@@ -1,22 +1,23 @@
 import os
 from typing import List
 
-from khl import Message, MessageTypes
+from khl import Message, MessageTypes, Bot
 
 from .plugin_interface import PluginInterface
 from .type.plugin import Plugin
+from ..utils.logger import ColoredLogger
 
 
 class PluginManager:
 
     plugins: List[Plugin]
 
-    def __init__(self, config, logger) -> None:
+    def __init__(self, config, logger: ColoredLogger) -> None:
         self.plugins = []
         self.config = config
         self.logger = logger
-        self.interface = PluginInterface(self)
-        self.interface.bot.client.register(MessageTypes.TEXT, self.on_message)
+        self.bot = Bot(self.config.token)
+        self.bot.client.register(MessageTypes.TEXT, self.on_message)
 
     def search_all_plugin(self):
         self.plugins.clear()
@@ -30,12 +31,16 @@ class PluginManager:
     def load_plugins(self):
         self.search_all_plugin()
         for plugin in self.plugins:
-            plugin.on_load(self.interface)
+            self.logger.info(f'插件 {plugin.meta.name}@{plugin.meta.id} V{plugin.meta.version} 已加载')
+            plugin.on_load(PluginInterface(self, plugin.meta.id))
 
     def unload_plugins(self):
         for plugin in self.plugins:
-            plugin.on_unload(self.interface)
+            plugin.on_unload(PluginInterface(self, plugin.meta.id))
 
     async def on_message(self, msg: Message):
+        self.logger.info(f'接收到消息: <{msg.author.nickname}> {msg.content}')
         for plugin in self.plugins:
             await plugin.on_message(msg)
+
+
